summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/html_dialog_view.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-03 03:05:11 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-03 03:05:11 +0000
commit4acc19a6f31abef9608546d10f107240603ca57e (patch)
tree632c914c428e94c05c8b9cb52cb183e62ae13e56 /chrome/browser/views/html_dialog_view.h
parent15936cdb983239ba2347e624af19e7305e416c7b (diff)
downloadchromium_src-4acc19a6f31abef9608546d10f107240603ca57e.zip
chromium_src-4acc19a6f31abef9608546d10f107240603ca57e.tar.gz
chromium_src-4acc19a6f31abef9608546d10f107240603ca57e.tar.bz2
Move HTML dialogs out of their own tab contents type. Moved functions to new
file html_dialog_ui.* Move WebContents view creation into the constructor, which makes a bunch of extra calls to CreateView unnecessary. Remove unused CallJavascriptFunction() functions in DOMUI. Review URL: http://codereview.chromium.org/56065 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@13065 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/views/html_dialog_view.h')
-rw-r--r--chrome/browser/views/html_dialog_view.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/browser/views/html_dialog_view.h b/chrome/browser/views/html_dialog_view.h
index 54bace6..bdff126 100644
--- a/chrome/browser/views/html_dialog_view.h
+++ b/chrome/browser/views/html_dialog_view.h
@@ -8,7 +8,7 @@
#include <string>
#include "base/gfx/size.h"
-#include "chrome/browser/dom_ui/html_dialog_contents.h"
+#include "chrome/browser/dom_ui/html_dialog_ui.h"
#include "chrome/browser/tab_contents/tab_contents_delegate.h"
#include "chrome/browser/views/dom_view.h"
#include "chrome/views/window/window_delegate.h"
@@ -22,7 +22,7 @@ class Window;
//
// HtmlDialogView is a view used to display an HTML dialog to the user. The
// content of the dialogs is determined by the delegate
// (HtmlDialogContentsDelegate), but is basically a file URL along with a
// JSON input string. The HTML is supposed to show a UI to the user and is
// expected to send back a JSON file as a return value.
//
@@ -30,12 +30,12 @@ class Window;
class HtmlDialogView
: public DOMView,
public TabContentsDelegate,
- public HtmlDialogContentsDelegate,
+ public HtmlDialogUIDelegate,
public views::WindowDelegate {
public:
HtmlDialogView(Browser* parent_browser,
Profile* profile,
- HtmlDialogContentsDelegate* delegate);
+ HtmlDialogUIDelegate* delegate);
virtual ~HtmlDialogView();
// Initializes the contents of the dialog (the DOMView and the callbacks).
@@ -52,7 +52,7 @@ class HtmlDialogView
virtual views::View* GetContentsView();
virtual views::View* GetInitiallyFocusedView();
- // Overridden from HtmlDialogContentsDelegate:
+ // Overridden from HtmlDialogUI::Delegate:
virtual bool IsDialogModal() const;
virtual std::wstring GetDialogTitle() const;
virtual GURL GetDialogContentURL() const;
@@ -95,7 +95,7 @@ class HtmlDialogView
// about when the dialog is closing. For all other actions (besides dialog
// closing) we delegate to the creator of this view, which we keep track of
// using this variable.
- HtmlDialogContentsDelegate* delegate_;
+ HtmlDialogUIDelegate* delegate_;
DISALLOW_COPY_AND_ASSIGN(HtmlDialogView);
};
@@ -22,7 +22,7 @@ class Window;
// HtmlDialogView is a view used to display an HTML dialog to the user. The
// content of the dialogs is determined by the delegate
-// (HtmlDialogContentsDelegate), but is basically a file URL along with a
+// (HtmlDialogUIDelegate), but is basically a file URL along with a
// JSON input string. The HTML is supposed to show a UI to the user and is
// expected to send back a JSON file as a return value.